@@ -25,7 +25,9 @@
 #include "cairo-image-surface-jpeg.h"
 #include "cairo-image-surface-png.h"
 #include "cairo-image-surface-svg.h"
+#include "cairo-image-surface-tiff.h"
 #include "cairo-image-surface-webp.h"
+#include "cairo-image-surface-xcf.h"
 #include "gth-image-saver-jpeg.h"
 #include "gth-image-saver-png.h"
 #include "gth-image-saver-tga.h"
@@ -61,6 +63,13 @@ gthumb_extension_activate (void)
 	gth_main_register_type ("image-saver", GTH_TYPE_IMAGE_SAVER_TGA);
 	gth_main_register_type ("image-saver", GTH_TYPE_IMAGE_SAVER_TIFF);
 
+#ifdef HAVE_LIBTIFF
+	gth_main_register_image_loader_func (_cairo_image_surface_create_from_tiff,
+					     GTH_IMAGE_FORMAT_CAIRO_SURFACE,
+					     "image/tiff",
+					     NULL);
+#endif
+
 #ifdef HAVE_LIBWEBP
 	gth_main_register_image_loader_func (_cairo_image_surface_create_from_webp,
 					     GTH_IMAGE_FORMAT_CAIRO_SURFACE,
@@ -69,6 +78,11 @@ gthumb_extension_activate (void)
 	gth_main_register_type ("image-saver", GTH_TYPE_IMAGE_SAVER_WEBP);
 #endif
 
+	gth_main_register_image_loader_func (_cairo_image_surface_create_from_xcf,
+					     GTH_IMAGE_FORMAT_CAIRO_SURFACE,
+					     "image/x-xcf",
+					     NULL);
+
 	gth_hook_add_callback ("dlg-preferences-construct", 30, G_CALLBACK (ci__dlg_preferences_construct_cb), NULL);
 	gth_hook_add_callback ("dlg-preferences-apply", 10, G_CALLBACK (ci__dlg_preferences_apply_cb), NULL);
 }
