@@ -115,6 +115,33 @@ _gth_window_add_header_bar (GthWindow *self)
 	self->priv->headerbar = gtk_header_bar_new ();
 	gtk_widget_show (self->priv->headerbar);
 	gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self->priv->headerbar), TRUE);
+
+#if GTK_CHECK_VERSION(3,12,0)
+	{
+		gboolean  shell_shows_app_menu;
+		char     *decoration_layout;
+
+		g_object_get (gtk_settings_get_default (),
+			      "gtk-shell-shows-app-menu", &shell_shows_app_menu,
+			      "gtk-decoration-layout", &decoration_layout,
+			      NULL);
+		if (! shell_shows_app_menu && ((decoration_layout == NULL) || (strstr (decoration_layout, "menu") == NULL))) {
+			gboolean  left_part_is_empty;
+			char     *new_layout;
+
+			/* add 'menu' to the left */
+
+			left_part_is_empty = (decoration_layout == NULL) || (decoration_layout[0] == '\0') || (decoration_layout[0] == ':');
+			new_layout = g_strconcat ("menu", (left_part_is_empty ? "" : ","), decoration_layout, NULL);
+			gtk_header_bar_set_decoration_layout (GTK_HEADER_BAR (self->priv->headerbar), new_layout);
+
+			g_free (new_layout);
+		}
+
+		g_free (decoration_layout);
+	}
+#endif
+
 	self->priv->title = gth_window_title_new ();
 	gtk_widget_show (self->priv->title);
 	gtk_header_bar_set_custom_title (GTK_HEADER_BAR (self->priv->headerbar), self->priv->title);
@@ -225,21 +252,17 @@ gth_window_real_set_current_page (GthWindow *window,
 
 
 static void
-gth_window_realize (GtkWidget *widget)
+_gth_window_add_css_provider (GtkWidget  *widget,
+			      const char *path)
 {
-	GdkScreen      *screen;
 	GBytes         *bytes;
 	gconstpointer   css_data;
 	gsize           css_data_size;
 	GtkCssProvider *css_provider;
 	GError         *error = NULL;
 
-	GTK_WIDGET_CLASS (gth_window_parent_class)->realize (widget);
 
-	screen = gtk_widget_get_screen (widget);
-	gtk_icon_theme_append_search_path (gtk_icon_theme_get_for_screen (screen), GTHUMB_ICON_DIR);
-
-	bytes = g_resources_lookup_data ("/org/gnome/gThumb/resources/gthumb.css", 0, &error);
+	bytes = g_resources_lookup_data (path, 0, &error);
 	if (bytes == NULL) {
 		g_warning ("%s", error->message);
 		g_error_free (error);
@@ -252,7 +275,7 @@ gth_window_realize (GtkWidget *widget)
 		g_warning ("%s", error->message);
 		g_error_free (error);
 	}
-	gtk_style_context_add_provider_for_screen (screen,
+	gtk_style_context_add_provider_for_screen (gtk_widget_get_screen (widget),
 						   GTK_STYLE_PROVIDER (css_provider),
 						   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
@@ -261,6 +284,21 @@ gth_window_realize (GtkWidget *widget)
 }
 
 
+static void
+gth_window_realize (GtkWidget *widget)
+{
+	GTK_WIDGET_CLASS (gth_window_parent_class)->realize (widget);
+
+	gtk_icon_theme_append_search_path (gtk_icon_theme_get_for_screen (gtk_widget_get_screen (widget)), GTHUMB_ICON_DIR);
+
+	_gth_window_add_css_provider (widget, "/org/gnome/gThumb/resources/gthumb.css");
+	if ((gtk_major_version >= 3) && (gtk_minor_version >= 14))
+		_gth_window_add_css_provider (widget, "/org/gnome/gThumb/resources/gthumb-gtk314.css");
+	else if ((gtk_major_version >= 3) && (gtk_minor_version >= 10))
+		_gth_window_add_css_provider (widget, "/org/gnome/gThumb/resources/gthumb-gtk312.css");
+}
+
+
 static void
 gth_window_class_init (GthWindowClass *klass)
 {
